==> atril-devel-1.18.0-1.tar.xz: usr/include/atril/1.5.0/libdocument/ev-document-type-builtins.h <==

/* Generated data (by glib-mkenums) */


#if !defined (__EV_ATRIL_DOCUMENT_H_INSIDE__) && !defined (ATRIL_COMPILATION)
#error "Only <atril-document.h> can be included directly."
#endif

#ifndef EV_DOCUMENT_TYPE_BUILTINS_H
#define EV_DOCUMENT_TYPE_BUILTINS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-annotation.h" */
GType ev_annotation_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATION_TYPE (ev_annotation_type_get_type ())
GType ev_annotation_text_icon_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATION_TEXT_ICON (ev_annotation_text_icon_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-document-annotations.h" */
GType ev_annotations_save_mask_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATIONS_SAVE_MASK (ev_annotations_save_mask_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-document.h" */
GType ev_document_error_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_ERROR (ev_document_error_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-document-info.h" */
GType ev_document_layout_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_LAYOUT (ev_document_layout_get_type ())
GType ev_document_mode_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_MODE (ev_document_mode_get_type ())
GType ev_document_ui_hints_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_UI_HINTS (ev_document_ui_hints_get_type ())
GType ev_document_permissions_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_PERMISSIONS (ev_document_permissions_get_type ())
GType ev_document_info_fields_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_INFO_FIELDS (ev_document_info_fields_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-file-exporter.h" */
GType ev_file_exporter_format_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FILE_EXPORTER_FORMAT (ev_file_exporter_format_get_type ())
GType ev_file_exporter_capabilities_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FILE_EXPORTER_CAPABILITIES (ev_file_exporter_capabilities_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-file-helpers.h" */
GType ev_compression_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_COMPRESSION_TYPE (ev_compression_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-form-field.h" */
GType ev_form_field_text_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_TEXT_TYPE (ev_form_field_text_type_get_type ())
GType ev_form_field_button_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_BUTTON_TYPE (ev_form_field_button_type_get_type ())
GType ev_form_field_choice_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_CHOICE_TYPE (ev_form_field_choice_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-link-action.h" */
GType ev_link_action_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_LINK_ACTION_TYPE (ev_link_action_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-link-dest.h" */
GType ev_link_dest_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_LINK_DEST_TYPE (ev_link_dest_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-selection.h" */
GType ev_selection_style_get_type (void) G_GNUC_CONST;
#define EV_TYPE_SELECTION_STYLE (ev_selection_style_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.i686/src/atril-1.18.0/libdocument/ev-transition-effect.h" */
GType ev_transition_effect_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_TYPE (ev_transition_effect_type_get_type ())
GType ev_transition_effect_alignment_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_ALIGNMENT (ev_transition_effect_alignment_get_type ())
GType ev_transition_effect_direction_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_DIRECTION (ev_transition_effect_direction_get_type ())
G_END_DECLS

#endif /* !EV_DOCUMENT_TYPE_BUILTINS_H */

/* Generated data ends here */

==> atril-devel-1.18.1-1.tar.xz: usr/include/atril/1.5.0/libdocument/ev-document-type-builtins.h <==

/* Generated data (by glib-mkenums) */


#if !defined (__EV_ATRIL_DOCUMENT_H_INSIDE__) && !defined (ATRIL_COMPILATION)
#error "Only <atril-document.h> can be included directly."
#endif

#ifndef EV_DOCUMENT_TYPE_BUILTINS_H
#define EV_DOCUMENT_TYPE_BUILTINS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-annotation.h" */
GType ev_annotation_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATION_TYPE (ev_annotation_type_get_type ())
GType ev_annotation_text_icon_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATION_TEXT_ICON (ev_annotation_text_icon_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-document-annotations.h" */
GType ev_annotations_save_mask_get_type (void) G_GNUC_CONST;
#define EV_TYPE_ANNOTATIONS_SAVE_MASK (ev_annotations_save_mask_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-document-info.h" */
GType ev_document_layout_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_LAYOUT (ev_document_layout_get_type ())
GType ev_document_mode_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_MODE (ev_document_mode_get_type ())
GType ev_document_ui_hints_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_UI_HINTS (ev_document_ui_hints_get_type ())
GType ev_document_permissions_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_PERMISSIONS (ev_document_permissions_get_type ())
GType ev_document_info_fields_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_INFO_FIELDS (ev_document_info_fields_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-document.h" */
GType ev_document_error_get_type (void) G_GNUC_CONST;
#define EV_TYPE_DOCUMENT_ERROR (ev_document_error_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-file-exporter.h" */
GType ev_file_exporter_format_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FILE_EXPORTER_FORMAT (ev_file_exporter_format_get_type ())
GType ev_file_exporter_capabilities_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FILE_EXPORTER_CAPABILITIES (ev_file_exporter_capabilities_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-file-helpers.h" */
GType ev_compression_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_COMPRESSION_TYPE (ev_compression_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-form-field.h" */
GType ev_form_field_text_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_TEXT_TYPE (ev_form_field_text_type_get_type ())
GType ev_form_field_button_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_BUTTON_TYPE (ev_form_field_button_type_get_type ())
GType ev_form_field_choice_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_FORM_FIELD_CHOICE_TYPE (ev_form_field_choice_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-link-action.h" */
GType ev_link_action_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_LINK_ACTION_TYPE (ev_link_action_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-link-dest.h" */
GType ev_link_dest_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_LINK_DEST_TYPE (ev_link_dest_type_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-selection.h" */
GType ev_selection_style_get_type (void) G_GNUC_CONST;
#define EV_TYPE_SELECTION_STYLE (ev_selection_style_get_type ())

/* enumerations from "/usr/src/ports/atril/atril-1.18.1-1.x86_64/src/atril-1.18.1/libdocument/ev-transition-effect.h" */
GType ev_transition_effect_type_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_TYPE (ev_transition_effect_type_get_type ())
GType ev_transition_effect_alignment_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_ALIGNMENT (ev_transition_effect_alignment_get_type ())
GType ev_transition_effect_direction_get_type (void) G_GNUC_CONST;
#define EV_TYPE_TRANSITION_EFFECT_DIRECTION (ev_transition_effect_direction_get_type ())
G_END_DECLS

#endif /* !EV_DOCUMENT_TYPE_BUILTINS_H */

/* Generated data ends here */
